@@ -1,14 +1,13 @@
 package Music::Intervals;
 our $AUTHORITY = 'cpan:GENE';
 
-# ABSTRACT: Mathematical breakdown of musical intervals
+# ABSTRACT: Breakdown of musical intervals
 
 use strict;
 use warnings;
 
-our $VERSION = '0.0507';
+our $VERSION = '0.0600';
 
-use Moo;
 use Algorithm::Combinatorics qw( combinations );
 use Math::Factor::XS qw( prime_factors );
 use Music::Chord::Namer qw( chordname );
@@ -16,6 +15,9 @@ use MIDI::Pitch qw( name2freq );
 use Number::Fraction;
 use Music::Scales;
 use Music::Intervals::Ratios;
+use Moo;
+use strictures 2;
+use namespace::clean;
 
 
 has cents     => ( is => 'ro', default => sub { 0 } );
@@ -37,64 +39,77 @@ has semitones => ( is => 'ro', default => sub { 12 } );
 has temper => (
     is      => 'ro',
     lazy    => 1,
-    default => sub {
-        my $self = shift;
-        $self->semitones * 100 / log(2);
-    },
+    builder => 1,
 );
+sub _build_temper {
+    my $self = shift;
+    $self->semitones * 100 / log(2);
+}
+
 has notes => (
     is      => 'ro',
     lazy    => 1,
-    default => sub {
-        my $self = shift;
-        return [ get_scale_notes( $self->tonic ) ]
-    },
+    builder => 1,
 );
+sub _build_notes {
+    my $self = shift;
+    return [ get_scale_notes( $self->tonic ) ];
+}
+
 has scale => (
     is      => 'ro',
     lazy    => 1,
-    default => sub {
-        my $self = shift;
-        return [ map { eval "$Music::Intervals::Ratios::ratio->{$_}{ratio}" } @{ $self->notes } ]
-    },
+    builder => 1,
 );
+sub _build_scale {
+    my $self = shift;
+    return [ map { eval "$Music::Intervals::Ratios::ratio->{$_}{ratio}" } @{ $self->notes } ];
+}
+
 has _note_index => (
     is      => 'ro',
     lazy    => 1,
-    default => sub {
-        my $self = shift;
-        return { map { $_ => eval "$Music::Intervals::Ratios::ratio->{$_}{ratio}" } @{ $self->notes } }
-    },
+    builder => 1,
 );
+sub _build__note_index {
+    my $self = shift;
+    return { map { $_ => eval "$Music::Intervals::Ratios::ratio->{$_}{ratio}" } @{ $self->notes } };
+}
+
 has _ratio_index => (
     is      => 'ro',
     lazy    => 1,
-    default => sub {
-        my $self = shift;
-        return { map { $_ => $Music::Intervals::Ratios::ratio->{$_}{ratio} } @{ $self->notes } }
-    },
+    builder => 1,
 );
+sub _build__ratio_index {
+    my $self = shift;
+    return { map { $_ => $Music::Intervals::Ratios::ratio->{$_}{ratio} } @{ $self->notes } };
+}
+
 has _ratio_name_index => (
     is      => 'ro',
     lazy    => 1,
-    default => sub {
-        my $self = shift;
-        return {
-            map { $Music::Intervals::Ratios::ratio->{$_}{ratio} => {
-                symbol => $_,
-                name   => $Music::Intervals::Ratios::ratio->{$_}{name} }
-            } keys %$Music::Intervals::Ratios::ratio
-        }
-    },
+    builder => 1,
 );
+sub _build__ratio_name_index {
+    my $self = shift;
+    return {
+        map { $Music::Intervals::Ratios::ratio->{$_}{ratio} => {
+            symbol => $_,
+            name   => $Music::Intervals::Ratios::ratio->{$_}{name} }
+        } keys %$Music::Intervals::Ratios::ratio
+    }
+}
+
 has tonic_frequency => (
     is      => 'ro',
     lazy    => 1,
-    default => sub {
-        my $self = shift;
-        return $self->concert * (2 ** (1 / $self->semitones)) ** (-9) # XXX Hardcoding: 9th key above middle-C
-    },
+    builder => 1,
 );
+sub _build_tonic_frequency {
+    my $self = shift;
+    return $self->concert * (2 ** (1 / $self->semitones)) ** (-9); # XXX Hardcoding: 9th key above middle-C
+}
 
 has chord_names             => ( is => 'rw', default => sub { {} } );
 has natural_frequencies     => ( is => 'rw', default => sub { {} } );
@@ -107,8 +122,9 @@ has eq_tempered_cents       => ( is => 'rw', default => sub { {} } );
 has integer_notation        => ( is => 'rw', default => sub { {} } );
 
 
-sub process
-{
+sub process {}
+
+sub BUILD {
     my $self = shift;
 
     my $iter = combinations( $self->notes, $self->size );
@@ -173,7 +189,7 @@ sub process
                 $self->natural_prime_factors->{"@$c natural_prime_factors"} = {
                     map {
                         $_ => {
-                            $dyads{$_}->{natural} => ratio_factorize( $dyads{$_}->{natural} )
+                            $dyads{$_}->{natural} => $self->ratio_factorize( $dyads{$_}->{natural} )
                         }
                     } keys %dyads
                 };
@@ -225,9 +241,9 @@ sub dyads
         my $denominator = Number::Fraction->new( $self->_ratio_index->{ $i->[0] } );
         my $fraction = $numerator / $denominator;
 
-        my $str = $fraction->to_string();
+        my $str = $fraction->to_string;
         # Handle the octave.
-        $str .= '/1' if $fraction->to_string() eq 2;
+        $str .= '/1' if $fraction->to_string eq 2;
 
         # Calculate both natural and equal temperament values for our ratio.
         $dyads{"@$i"} = {
@@ -245,7 +261,7 @@ sub dyads
 
 
 sub ratio_factorize {
-    my $dyad = shift;
+    my ($self, $dyad) = @_;
 
     my ( $numerator, $denominator ) = split /\//, $dyad;
     $numerator   = [ prime_factors($numerator) ];
@@ -281,11 +297,11 @@ __END__
 
 =head1 NAME
 
-Music::Intervals - Mathematical breakdown of musical intervals
+Music::Intervals - Breakdown of musical intervals
 
 =head1 VERSION
 
-version 0.0507
+version 0.0600
 
 =head1 SYNOPSIS
 
@@ -304,10 +320,8 @@ version 0.0507
     integer  => 1,             # Required for integer notation
   );
 
-  $m->process;
-
   # Then
-  print Dumper # any of:
+  print Dumper(
     $m->chord_names,
     $m->natural_frequencies,
     $m->natural_intervals,
@@ -317,19 +331,19 @@ version 0.0507
     $m->eq_tempered_intervals,
     $m->eq_tempered_cents,
     $m->integer_notation,
-  ;
+  );
 
   # Find known intervals
   $name  = $m->by_ratio($ratio);
   $ratio = $m->by_name($interval_name);
 
-  # Show all the known intervals:
+  # Show all the 447 known intervals:
   perl -MData::Dumper -MMusic::Intervals::Ratios -e'print Dumper $Music::Intervals::Ratios::ratio'
 
 =head1 DESCRIPTION
 
-A C<Music::Intervals> object shows the mathematical break-down of musical notes,
-intervals and chords.
+A C<Music::Intervals> object shows the breakdown of musical notes, intervals and
+chords.
 
 This module reveals the "guts" within a given tonality.  And by guts I mean, the
 measurements of the notes and the intervals between them.
@@ -441,12 +455,12 @@ those of the common scale and even the Pythagorean intervals, too.
 
 A few examples:
 
- * [qw( C E G )]
- * [qw( C D D# )]
- * [qw( C D Eb )]
- * [qw( C D D# Eb E E# Fb F )]
- * [qw( C 11h 7h )]
- * [qw( C pM3 pM7 )]
+ [qw( C E G )]
+ [qw( C D D# )]
+ [qw( C D Eb )]
+ [qw( C D D# Eb E E# Fb F )]
+ [qw( C 11h 7h )]
+ [qw( C pM3 pM7 )]
 
 For B<natural_intervals> this last example produces the following:
 
@@ -501,32 +515,32 @@ Computed hashref
 
 =head1 METHODS
 
-=head2 new()
+=head2 new
 
   $x = Music::Intervals->new(%arguments);
 
 Create a new C<Music::Intervals> object.
 
-=head2 process()
+=for Pod::Coverage process
 
-Do the actual computations!
+=for Pod::Coverage BUILD
 
-=head2 dyads()
+=head2 dyads
 
-Return pairs of the given combinations with fractional and pitch ratio parts.
+Return pairs of the given notes with fractional and pitch ratio parts.
 
-=head2 ratio_factorize()
+=head2 ratio_factorize
 
 Return the dyadic fraction as a prime factored expression.
 
-=head2 by_name()
+=head2 by_name
 
  $ratio = $m->by_name('C');
  # { ratio => '1/1', name => 'unison, perfect prime, tonic' }
 
 Return a known ratio or undef.
 
-=head2 by_ratio()
+=head2 by_ratio
 
  $name = $m->by_ratio('1/1');
  # { 'symbol' => 'C', 'name' => 'unison, perfect prime, tonic' }
@@ -556,7 +570,7 @@ Gene Boggs <gene@cpan.org>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2019 by Gene Boggs.
+This software is copyright (c) 2021 by Gene Boggs.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
